@@ -1,4 +1,7 @@
-#    Copyright 2021 Environment and Climate Change Canada
+# Copyright 2015-2023 Province of British Columbia
+# Copyright 2021 Environment and Climate Change Canada
+# Copyright 2023-2024 Australian Government Department of Climate Change, 
+# Energy, the Environment and Water
 #
 #    Licensed under the Apache License, Version 2.0 (the "License");
 #    you may not use this file except in compliance with the License.
@@ -28,7 +31,8 @@ optimizer_converged <- function(fit) {
 optimizer_message <- function(fit) {
   code <- as.character(optim_convergence(fit))
   switch(code,
-    "1" =  "Iteration limit maxit reach (try increasing the maximum number of iterations in control).",
+    "1" = "Iteration limit maxit reach (try increasing the maximum number of iterations in control).",
     "10" = "Degeneracy of Nelder-Mead simplex.",
-    optim_message(fit))
+    optim_message(fit)
+  )
 }
