@@ -19,7 +19,7 @@ release_questions <- function() {
   c(
     "Have you run `data-raw/data-raw.R`?",
     "Have you tested using `ssdtests` package?",
-    "Have you updated `small-sample-bias.pdf`?",
+    "Have you run `vignettestatic/small-sample-bias.Rmd`?",
     "Have you confirmed all images in .Rmd files have alternative text defined using the `fig.alt` argument?",
     "Have you confirmed updated Apache 2.0 license at the top of all code files?",
     "Have you confirmed update Creative Commons license for all non-code files?"
