@@ -24,10 +24,6 @@
 #' @export
 dgompertz <- function(x, llocation = 0, lshape = 0, log = FALSE) {
   lifecycle::deprecate_stop("1.0.0", "dgompertz()")
-  ddist("gompertz", x,
-    location = exp(llocation), shape = exp(lshape),
-    log = log
-  )
 }
 
 #' @describeIn ssd_p Cumulative Distribution Function for Gompertz Distribution
@@ -44,14 +40,13 @@ ssd_pgompertz <- function(q, location = 1, shape = 1, lower.tail = TRUE, log.p =
 
 #' Cumulative Distribution Function for Gompertz Distribution
 #' `r lifecycle::badge("deprecated")`
+#' 
+#' Deprecated for `ssd_pgompertz()`.
+#' 
 #' @inheritParams params
 #' @export
 pgompertz <- function(q, llocation = 0, lshape = 0, lower.tail = TRUE, log.p = FALSE) {
   lifecycle::deprecate_stop("1.0.0", "pgompertz()", "ssd_pgompertz()")
-  ssd_pgompertz(q,
-    location = exp(llocation), shape = exp(lshape),
-    lower.tail = lower.tail, log.p = log.p
-  )
 }
 
 #' @describeIn ssd_q Quantile Function for Gompertz Distribution
@@ -68,14 +63,13 @@ ssd_qgompertz <- function(p, location = 1, shape = 1, lower.tail = TRUE, log.p =
 
 #' Quantile Function for Gompertz Distribution
 #' `r lifecycle::badge("deprecated")`
+#' 
+#' Deprecated for `ssd_qgompertz()`.
+#' 
 #' @inheritParams params
 #' @export
 qgompertz <- function(p, llocation = 0, lshape = 0, lower.tail = TRUE, log.p = FALSE) {
   lifecycle::deprecate_stop("1.0.0", "qgompertz()", "ssd_qgompertz()")
-  ssd_qgompertz(
-    p = p, location = exp(llocation), shape = exp(lshape),
-    lower.tail = lower.tail, log.p = log.p
-  )
 }
 
 #' @describeIn ssd_r Random Generation for Gompertz Distribution
@@ -99,11 +93,13 @@ ssd_egompertz <- function() {
 
 #' Random Generation for Gompertz Distribution
 #' `r lifecycle::badge("deprecated")`
+#' 
+#' Deprecated for `ssd_rgompertz()`.
+#' 
 #' @inheritParams params
 #' @export
 rgompertz <- function(n, llocation = 0, lshape = 0) {
   lifecycle::deprecate_stop("1.0.0", "rgompertz()", "ssd_rgompertz()")
-  ssd_rgompertz(n = n, location = exp(llocation), shape = exp(lshape))
 }
 
 sgompertz <- function(data, pars = NULL) {
