@@ -1,4 +1,7 @@
-#    Copyright 2021 Province of British Columbia
+# Copyright 2015-2023 Province of British Columbia
+# Copyright 2021 Environment and Climate Change Canada
+# Copyright 2023-2024 Australian Government Department of Climate Change, 
+# Energy, the Environment and Water
 #
 #    Licensed under the Apache License, Version 2.0 (the "License");
 #    you may not use this file except in compliance with the License.
@@ -17,11 +20,13 @@ stats::logLik
 
 #' @export
 logLik.tmbfit <- function(object, ...) {
+  chk_unused(...)
   .objective_tmbfit(object) * -1
 }
 
 #' @export
 logLik.fitdists <- function(object, ...) {
+  chk_unused(...)
   object <- vapply(object, logLik, 1)
   object
 }
