@@ -20,7 +20,7 @@
 #' @examples
 #'
 #' # multi
-#' ssd_pmulti(1)
+#' ssd_pmulti(1, gamma.weight = 0.5, lnorm.weight = 0.5)
 ssd_pmulti <- function(
     q,
     burrIII3.weight = 0,
@@ -48,7 +48,7 @@ ssd_pmulti <- function(
     llogis_llogis.locationlog2 = 1,
     llogis_llogis.scalelog2 = 1,
     llogis_llogis.pmix = 0.5,
-    lnorm.weight = 1,
+    lnorm.weight = 0,
     lnorm.meanlog = 0,
     lnorm.sdlog = 1,
     lnorm_lnorm.weight = 0,
@@ -109,7 +109,7 @@ ssd_pmulti <- function(
 #' @examples
 #'
 #' # multi
-#' ssd_qmulti(0.5)
+#' ssd_qmulti(0.5, gamma.weight = 0.5, lnorm.weight = 0.5)
 ssd_qmulti <- function(
     p,
     burrIII3.weight = 0,
@@ -137,7 +137,7 @@ ssd_qmulti <- function(
     llogis_llogis.locationlog2 = 1,
     llogis_llogis.scalelog2 = 1,
     llogis_llogis.pmix = 0.5,
-    lnorm.weight = 1,
+    lnorm.weight = 0,
     lnorm.meanlog = 0,
     lnorm.sdlog = 1,
     lnorm_lnorm.weight = 0,
@@ -199,10 +199,7 @@ ssd_qmulti <- function(
 #'
 #' # multi
 #' set.seed(50)
-#' hist(ssd_rmulti(1000), breaks = 100)
-#'
-#' fits <- ssd_fit_dists(ssddata::ccme_boron)
-#' do.call("ssd_rmulti", c(n = 10, estimates(fits)))
+#' hist(ssd_rmulti(1000, gamma.weight = 0.5, lnorm.weight = 0.5), breaks = 100)
 ssd_rmulti <- function(
     n,
     burrIII3.weight = 0,
@@ -230,7 +227,7 @@ ssd_rmulti <- function(
     llogis_llogis.locationlog2 = 1,
     llogis_llogis.scalelog2 = 1,
     llogis_llogis.pmix = 0.5,
-    lnorm.weight = 1,
+    lnorm.weight = 0,
     lnorm.meanlog = 0,
     lnorm.sdlog = 1,
     lnorm_lnorm.weight = 0,
@@ -296,24 +293,48 @@ ssd_emulti <- function() {
   as.list(unlist(emulti))
 }
 
-.ssd_pmulti_fitdists <- function(q, fitdists, lower.tail = TRUE, log.p = FALSE) {
-  args <- estimates(fitdists, all_estimates = TRUE)
+#' @describeIn ssd_p Cumulative Distribution Function for Multiple Distributions
+#' @export
+#' @examples
+#'
+#' # multi fitdists
+#' fit <- ssd_fit_dists(ssddata::ccme_boron)
+#' ssd_pmulti_fitdists(1, fit)
+ssd_pmulti_fitdists <- function(q, fitdists, lower.tail = TRUE, log.p = FALSE) {
+  chk_s3_class(fitdists, "fitdists")
+  args <- estimates(fitdists)
   args$q <- q
   args$lower.tail <- lower.tail
   args$log.p <- log.p
   do.call("ssd_pmulti", args)
 }
 
-.ssd_qmulti_fitdists <- function(p, fitdists, lower.tail = TRUE, log.p = FALSE) {
-  args <- estimates(fitdists, all_estimates = TRUE)
+#' @describeIn ssd_q Quantile Function for Multiple Distributions
+#' @export
+#' @examples
+#'
+#' # multi fitdists
+#' fit <- ssd_fit_dists(ssddata::ccme_boron)
+#' ssd_qmulti_fitdists(0.5, fit)
+ssd_qmulti_fitdists <- function(p, fitdists, lower.tail = TRUE, log.p = FALSE) {
+  chk_s3_class(fitdists, "fitdists")
+  args <- estimates(fitdists)
   args$p <- p
   args$lower.tail <- lower.tail
   args$log.p <- log.p
   do.call("ssd_qmulti", args)
 }
 
-.ssd_rmulti_fitdists <- function(n, fitdists, chk = TRUE) {
-  args <- estimates(fitdists, all_estimates = TRUE)
+#' @describeIn ssd_r Random Generation for Multiple Distributions
+#' @export
+#' @examples
+#'
+#' # multi fitdists
+#' fit <- ssd_fit_dists(ssddata::ccme_boron)
+#' ssd_rmulti_fitdists(2, fit)
+ssd_rmulti_fitdists <- function(n, fitdists, chk = TRUE) {
+  chk_s3_class(fitdists, "fitdists")
+  args <- estimates(fitdists)
   args$n <- n
   args$chk <- chk
   do.call("ssd_rmulti", args)
