@@ -1,4 +1,7 @@
-#    Copyright 2021 Province of British Columbia
+# Copyright 2015-2023 Province of British Columbia
+# Copyright 2021 Environment and Climate Change Canada
+# Copyright 2023-2024 Australian Government Department of Climate Change, 
+# Energy, the Environment and Water
 #
 #    Licensed under the Apache License, Version 2.0 (the "License");
 #    you may not use this file except in compliance with the License.
@@ -12,13 +15,14 @@
 #    See the License for the specific language governing permissions and
 #    limitations under the License.
 
-
 #' @export
 stats::nobs
 
 #' @export
 nobs.fitdists <- function(object, ...) {
-  if(ssd_is_censored(object))
+  chk_unused(...)
+  if (ssd_is_censored(object)) {
     return(NA_integer_)
+  }
   nrow(.data_fitdists(object))
 }
