@@ -21,23 +21,12 @@
 #' Plots a Cullen and Frey graph of the skewness and kurtosis
 #' for non-censored data.
 #'
-#' Soft deprecated for direct call to [fitdistrplus::descdist()].
+#' Deprecated for [fitdistrplus::descdist()].
 #'
 #' @inheritParams ssd_fit_dists
 #' @export
 ssd_plot_cf <- function(data, left = "Conc") {
-  if (!requireNamespace("fitdistrplus", quietly = TRUE)) {
-    err("Package 'fitdistrplus' is required to produce Cullen and Frey plots.")
-  }
-
   lifecycle::deprecate_stop("0.3.5", "ssd_plot_cf()", "fitdistrplus::descdist()",
     details = "Please use fitdistrplus::descdist(data$Conc, boot = 100L)."
   )
-
-  chk_s3_class(data, "data.frame")
-  chk_string(left)
-  chk_superset(colnames(data), left)
-
-  fitdistrplus::descdist(data[[left]], boot = 100L)
-  invisible()
 }
