@@ -1,4 +1,7 @@
-#    Copyright 2021 Province of British Columbia
+# Copyright 2015-2023 Province of British Columbia
+# Copyright 2021 Environment and Climate Change Canada
+# Copyright 2023-2024 Australian Government Department of Climate Change, 
+# Energy, the Environment and Water
 #
 #    Licensed under the Apache License, Version 2.0 (the "License");
 #    you may not use this file except in compliance with the License.
@@ -13,6 +16,5 @@
 #    limitations under the License.
 
 test_that("cfplot", {
-  withr::local_options(lifecycle_verbosity = "quiet")
-  expect_snapshot_plot(ssd_plot_cf(ssddata::ccme_boron), "ccme_boron")
+  expect_defunct(ssd_plot_cf(ssddata::ccme_boron))
 })
